@@ -1,6 +1,6 @@
 package MooX::Const;
 
-# ABSTRACT: Syntactic sugar for creating constant Moo attributes
+# ABSTRACT: Syntactic sugar for constant and write-once Moo attributes
 
 use utf8;
 use v5.8;
@@ -14,7 +14,14 @@ use Types::Standard qw( Value Object Ref );
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.1.4';
+our $VERSION = 'v0.2.0';
+
+
+sub VERSION { # for older Perls
+    my ( $class, $wanted ) = @_;
+    require version;
+    return version->parse($VERSION);
+}
 
 
 sub import {
@@ -39,16 +46,31 @@ sub import {
 sub _process_has {
     my ( $name, %opts ) = @_;
 
-    if ( $opts{is} && $opts{is} eq 'const' ) {
+    my $is = $opts{is};
+
+    if ($is && $is =~ /^(?:const|wo)$/ ) {
 
         if ( my $isa = $opts{isa} ) {
 
-
             unless ( $isa->$_isa('Type::Tiny') ) {
                 croak "isa must be a Type::Tiny type";
             }
 
-            unless ($isa->is_a_type_of(Value)) {
+            if ($isa->is_a_type_of(Value)) {
+
+                if ($is eq 'wo') {
+
+                    croak "write-once attributes are not supported for Value types";
+
+                }
+                else {
+
+                    $opts{is}  = 'ro';
+
+                }
+
+            }
+            else {
 
                 unless ( $isa->is_a_type_of(Ref) ) {
                     croak "isa must be a type of Types::Standard::Ref";
@@ -61,9 +83,13 @@ sub _process_has {
                 $opts{isa} = Const[$isa];
                 $opts{coerce} = $opts{isa}->coercion;
 
-            }
+                if ($opts{trigger} && ($is ne 'wo')) {
+                    croak "triggers are not applicable to const attributes";
+                }
 
-            $opts{is}  = 'ro';
+                $opts{is}  = $is eq 'wo' ? 'rw' : 'ro';
+
+            }
 
         }
         else {
@@ -88,11 +114,11 @@ __END__
 
 =head1 NAME
 
-MooX::Const - Syntactic sugar for creating constant Moo attributes
+MooX::Const - Syntactic sugar for constant and write-once Moo attributes
 
 =head1 VERSION
 
-version v0.1.4
+version v0.2.0
 
 =head1 SYNOPSIS
 
@@ -130,6 +156,19 @@ object.
 Simple value types such as C<Int> or C<Str> are silently converted to
 read-only attributes.
 
+As of v0.2.0, it also supports write-once ("wo") attributes for
+references:
+
+  has setting => (
+    is  => 'wo',
+    isa => HashRef,
+  );
+
+This allows you to set the attribute I<once>. The value is coerced
+into a constant, and cannot be changed again.
+
+=for Pod::Coverage VERSION
+
 =head1 SEE ALSO
 
 L<Moo>
